==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/MoneyFlowIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MoneyFlowIndexIndicatorDescription } from "./MoneyFlowIndexIndicatorDescription";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MoneyFlowIndexIndicatorDescriptionMetadata.a == null) {
                MoneyFlowIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MoneyFlowIndexIndicatorDescriptionMetadata.c(MoneyFlowIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MoneyFlowIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(MoneyFlowIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            MoneyFlowIndexIndicatorDescriptionMetadata.b(a);
            a.ad("MoneyFlowIndexIndicator", () => new MoneyFlowIndexIndicatorDescription());
            a.ac("MoneyFlowIndexIndicator", MoneyFlowIndexIndicatorDescriptionMetadata.a);
        }
    }
    MoneyFlowIndexIndicatorDescriptionMetadata.$t = markType(MoneyFlowIndexIndicatorDescriptionMetadata, 'MoneyFlowIndexIndicatorDescriptionMetadata');
    MoneyFlowIndexIndicatorDescriptionMetadata.a = null;
    return MoneyFlowIndexIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/MoneyFlowIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MoneyFlowIndexIndicatorDescription } from "./MoneyFlowIndexIndicatorDescription";
/**
 * @hidden
 */
export let MoneyFlowIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MoneyFlowIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MoneyFlowIndexIndicatorDescriptionMetadata.a == null) {
                MoneyFlowIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MoneyFlowIndexIndicatorDescriptionMetadata.c(MoneyFlowIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MoneyFlowIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(MoneyFlowIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            MoneyFlowIndexIndicatorDescriptionMetadata.b(a);
            a.ae("MoneyFlowIndexIndicator", () => new MoneyFlowIndexIndicatorDescription());
            a.ad("MoneyFlowIndexIndicator", MoneyFlowIndexIndicatorDescriptionMetadata.a);
        }
    }
    MoneyFlowIndexIndicatorDescriptionMetadata.$t = markType(MoneyFlowIndexIndicatorDescriptionMetadata, 'MoneyFlowIndexIndicatorDescriptionMetadata');
    MoneyFlowIndexIndicatorDescriptionMetadata.a = null;
    return MoneyFlowIndexIndicatorDescriptionMetadata;
})();
